GenericClassMirrorImpl<T extends Object> class

Implemented types

Constructors

GenericClassMirrorImpl(String simpleName, String qualifiedName, int descriptor, int classIndex, ReflectionImpl reflector, List<int> declarationIndices, List<int>? instanceMemberIndices, List<int>? staticMemberIndices, int superclassIndex, Map<String, StaticGetter> getters, Map<String, InvokerOfGetter> setters, Map<String, Function> constructors, int ownerIndex, int mixinIndex, List<int> superinterfaceIndices, List<Object>? metadata, Map<String, int>? parameterListShapes, InstanceChecker _isGenericRuntimeTypeOf, List<int>? _typeVariableIndices, int _dynamicReflectedTypeIndex)

Properties

declarations Map<String, DeclarationMirror>
Returns an immutable map of the declarations actually given in the class declaration.
no setterinherited
dynamicReflectedType Type
If hasDynamicReflectedType returns true, returns the Type object representing the fully dynamic instantiation of this class if it is generic, and return the Type object representing this class if it is not generic. If hasDynamicReflectedType returns false it throws an UnsupportedError. The fully dynamic instantiation of a generic class C is the application of C to a type argument list of the appropriate length where every argument is dynamic. For instance, the fully dynamic instantiation of List and Map is List<dynamic> respectively Map<dynamic, dynamic>.
no setteroverride
hasDynamicReflectedType bool
Returns true if this mirror reflects dynamic, a non-generic class or typedef, or an instantiated generic class or typedef with support in the execution mode. Otherwise, returns false.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasReflectedType bool
Returns true if this mirror reflects dynamic, a non-generic class or typedef, or an instantiated generic class or typedef with support in the execution mode. Otherwise, returns false.
no setteroverride
instanceMembers Map<String, MethodMirror>
Returns a map of the methods, getters and setters of an instance of the class.
no setterinherited
isAbstract bool
Is the reflectee abstract?
no setterinherited
isEnum bool
Is the reflectee an enum?
no setterinherited
isNonNullable bool
Returns true iff this type mirror represents a non-nullable type.
no setterinherited
isNullable bool
Returns true iff this type mirror represents a nullable type.
no setterinherited
isOriginalDeclaration bool
Is this the original declaration of this type?
no setteroverride
isPotentiallyNonNullable bool
Returns true iff this type mirror represents a potentially non-nullable type.
no setterinherited
isPotentiallyNullable bool
Returns true iff this type mirror represents a potentially nullable type.
no setterinherited
isPrivate bool
Whether this declaration is library private.
no setterinherited
isTopLevel bool
Whether this declaration is top-level.
no setterinherited
location SourceLocation
The source location of this Dart language entity, or null if the entity is synthetic.
no setterinherited
metadata List<Object>
A list of the metadata associated with this declaration.
no setterinherited
mixin ClassMirror
The mixin of this class.
no setterinherited
originalDeclaration TypeMirror
A mirror on the original declaration of this type.
no setteroverride
owner DeclarationMirror
A mirror on the owner of this Dart language entity.
no setterinherited
qualifiedName String
finalinherited
reflectedGenericType Type
no setterinherited
reflectedType Type
If hasReflectedType returns true, returns the corresponding Type. Otherwise, an UnsupportedError is thrown.
no setteroverride
reflectedTypeArguments List<Type>
An immutable list with Type values for the actual type arguments of this type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleName String
finalinherited
staticMembers Map<String, MethodMirror>
Returns a map of the static methods, getters and setters of the class.
no setterinherited
superclass → ClassMirrorBase<Object>?
A mirror on the superclass on the reflectee.
no setterinherited
superinterfaces List<ClassMirror>
A list of mirrors on the superinterfaces of the reflectee.
no setterinherited
typeArguments List<TypeMirror>
An immutable list with mirrors for all type arguments for this type.
no setteroverride
typeVariables List<TypeVariableMirror>
An immutable list with mirrors for all type variables for this type.
no setteroverride

Methods

createInstantiatedGenericClassMirror(Object? instance, List<int>? reflectedTypeArgumentIndices, [int? descriptor]) → InstantiatedGenericClassMirrorImpl<T>
createKeyedMap<V>() Map<T, V>
inherited
createKeyedValuedMap() Map<T, T>
inherited
createList() List<T>
inherited
createNullableList() List<T?>
inherited
createNullableSet() Set<T?>
inherited
createNullableValuedMap<K>() Map<K, T?>
inherited
createSet() Set<T>
inherited
createValuedMap<K>() Map<K, T>
inherited
invoke(String memberName, List positionalArguments, [Map<Symbol, dynamic>? namedArguments]) Object?
Invokes the function or method memberName, and returns the result.
inherited
invokeGetter(String getterName) Object?
Invokes a getter and returns the result. The getter can be the implicit getter for a field, or a user-defined getter method.
inherited
invoker(String memberName) Function
Returns an invoker builder for the given memberName. An invoker builder is a closure that takes an object and returns an invoker for that object. The returned invoker is a closure that invokes the memberName on the object it is specialized for. In other words, the invoker-builder returns a tear-off of memberName for any given object that implements the class this ClassMirror reflects on.
inherited
invokeSetter(String name, Object? value) Object?
Invokes a setter and returns the result. The setter may be either the implicit setter for a non-final field, or a user-defined setter method. The name of the setter can include the final =; if it is not present, it will be added.
inherited
isAssignableTo(TypeMirror other) bool
Checks the assignability relationship, denoted by <=> in the language specification. This is the type relationship tested on assignment in checked mode.
inherited
isInstanceOf(Object? object) bool
inherited
isSubclassOf(ClassMirror other) bool
Returns whether the class denoted by the receiver is a subclass of the class denoted by the argument.
inherited
isSubtype<S>() bool
inherited
isSubtypeOf(TypeMirror other) bool
Checks the subtype relationship, denoted by <: in the language specification.
inherited
newInstance(String constructorName, List positionalArguments, [Map<Symbol, dynamic>? namedArguments]) Object
Invokes the named constructor and returns the result.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited