isOriginalDeclaration property

  1. @override
bool get isOriginalDeclaration
override

Is this the original declaration of this type?

For most classes, they are their own original declaration. For generic classes, however, there is a distinction between the original class declaration, which has unbound type variables, and the instantiations of generic classes, which have bound type variables.

Required capabilities: isOriginalDeclaration requires a TypeRelationsCapability.

Implementation

@override
bool get isOriginalDeclaration => true;