originalDeclaration property

  1. @override
TypeMirror get originalDeclaration
override

A mirror on the original declaration of this type.

For most classes, they are their own original declaration. For generic classes, however, there is a distinction between the original class declaration, which has unbound type variables, and the instantiations of generic classes, which have bound type variables.

Required capabilities: originalDeclaration requires a TypeRelationsCapability.

Implementation

@override
TypeMirror get originalDeclaration {
  if (!_supportsTypeRelations(_reflector)) {
    throw NoSuchCapabilityError(
      'Attempt to get `originalDeclaration` for `$qualifiedName` '
      'without `typeRelationsCapability`',
    );
  }
  return this;
}