ImplicitSetterMirrorImpl class

Implemented types

Constructors

ImplicitSetterMirrorImpl(ReflectionImpl reflector, int variableMirrorIndex, int selfIndex)

Properties

constructorName String
The constructor name for named constructors and factory methods.
no setterinherited
dynamicReflectedReturnType Type
If hasDynamicReflectedReturnType is true, returns the corresponding Type as specified for dynamicReflectedType in ClassMirror. Otherwise, an UnsupportedError is thrown.
no setterinherited
hasDynamicReflectedReturnType bool
Returns the value specified with hasDynamicReflectedType in ClassMirror, but for the return type given by the annotation of the method modeled by this mirror.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasReflectedReturnType bool
Returns the value specified with hasReflectedType in TypeMirror, but for the return type given by the annotation of the method modeled by this mirror.
no setterinherited
isAbstract bool
Is the reflectee abstract?
no setterinherited
isConstConstructor bool
Is the reflectee a const constructor?
no setterinherited
isConstructor bool
Is the reflectee a constructor?
no setterinherited
isFactoryConstructor bool
Is the reflectee a factory constructor?
no setterinherited
isGenerativeConstructor bool
Is the reflectee a generative constructor?
no setterinherited
isGetter bool
Is the reflectee a getter?
no setteroverride
isOperator bool
Is the reflectee an operator?
no setterinherited
isPrivate bool
Whether this declaration is library private.
no setterinherited
isRedirectingConstructor bool
Is the reflectee a redirecting constructor?
no setterinherited
isRegularMethod bool
Is the reflectee a regular function or method?
no setterinherited
isSetter bool
Is the reflectee a setter?
no setteroverride
isStatic bool
A function is considered non-static iff it is permited to refer to 'this'.
no setterinherited
isSynthetic bool
Returns true if the reflectee is synthetic, and returns false otherwise.
no setterinherited
isTopLevel bool
Whether this declaration is top-level.
no setterinherited
kind int
no setterinherited
location SourceLocation
The source location of this Dart language entity, or null if the entity is synthetic.
no setterinherited
metadata List<Object>
A list of the metadata associated with this declaration.
no setterinherited
owner DeclarationMirror
A mirror on the owner of this Dart language entity.
no setterinherited
parameters List<ParameterMirror>
A list of mirrors on the parameters for the reflectee.
no setteroverride
qualifiedName String
The fully-qualified name for this Dart language entity.
no setteroverride
reflectedReturnType Type
If hasReflectedReturnType is true, returns the corresponding Type. Otherwise, an UnsupportedError is thrown.
no setterinherited
returnType TypeMirror
A mirror on the return type for the reflectee.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleName String
The simple name for this Dart language entity.
no setteroverride
source String?
The source code for the reflectee, if available. Otherwise null.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited