simpleName property

  1. @override
String simpleName
final

The simple name for this Dart language entity.

The simple name is in most cases the the identifier name of the entity, such as 'myMethod' for a method, void myMethod() {...} or 'mylibrary' for a library 'mylibrary'; declaration.

Required capabilities: simpleName does not require any capabilities.

Implementation

@override
final String simpleName;