MethodMirrorImpl class

Implemented types

Constructors

MethodMirrorImpl(String _name, int _descriptor, int _ownerIndex, int _returnTypeIndex, int _reflectedReturnTypeIndex, int _dynamicReflectedReturnTypeIndex, List<int>? _reflectedTypeArgumentsOfReturnType, List<int> _parameterIndices, ReflectionImpl _reflector, List<Object>? _metadata)

Properties

constructorName String
The constructor name for named constructors and factory methods.
no setteroverride
dynamicReflectedReturnType Type
If hasDynamicReflectedReturnType is true, returns the corresponding Type as specified for dynamicReflectedType in ClassMirror. Otherwise, an UnsupportedError is thrown.
no setteroverride
hasDynamicReflectedReturnType bool
Returns the value specified with hasDynamicReflectedType in ClassMirror, but for the return type given by the annotation of the method modeled by this mirror.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasReflectedReturnType bool
Returns the value specified with hasReflectedType in TypeMirror, but for the return type given by the annotation of the method modeled by this mirror.
no setteroverride
isAbstract bool
Is the reflectee abstract?
no setteroverride
isConstConstructor bool
Is the reflectee a const constructor?
no setteroverride
isConstructor bool
Is the reflectee a constructor?
no setteroverride
isFactoryConstructor bool
Is the reflectee a factory constructor?
no setteroverride
isGenerativeConstructor bool
Is the reflectee a generative constructor?
no setteroverride
isGetter bool
Is the reflectee a getter?
no setteroverride
isOperator bool
Is the reflectee an operator?
no setteroverride
isPrivate bool
Whether this declaration is library private.
no setteroverride
isRedirectingConstructor bool
Is the reflectee a redirecting constructor?
no setteroverride
isRegularMethod bool
Is the reflectee a regular function or method?
no setteroverride
isSetter bool
Is the reflectee a setter?
no setteroverride
isStatic bool
A function is considered non-static iff it is permited to refer to 'this'.
no setteroverride
isSynthetic bool
Returns true if the reflectee is synthetic, and returns false otherwise.
no setteroverride
isTopLevel bool
Whether this declaration is top-level.
no setteroverride
kind int
no setter
location SourceLocation
The source location of this Dart language entity, or null if the entity is synthetic.
no setteroverride
metadata List<Object>
A list of the metadata associated with this declaration.
no setteroverride
namesOfNamedParameters Set<Symbol>
Returns the Set of Symbols used for named parameters of this method; computed based on the given parameter mirrors, then cached.
no setter
numberOfOptionalPositionalParameters int
Returns the number of optional positional parameters of this method; computed from the given parameter mirrors, then cached.
no setter
numberOfPositionalParameters int
Returns the number of positional parameters of this method; computed from the given parameter mirrors, then cached.
no setter
owner DeclarationMirror
A mirror on the owner of this Dart language entity.
no setteroverride
parameters List<ParameterMirror>
A list of mirrors on the parameters for the reflectee.
no setteroverride
qualifiedName String
The fully-qualified name for this Dart language entity.
no setteroverride
reflectedReturnType Type
If hasReflectedReturnType is true, returns the corresponding Type. Otherwise, an UnsupportedError is thrown.
no setteroverride
returnType TypeMirror
A mirror on the return type for the reflectee.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleName String
The simple name for this Dart language entity.
no setteroverride
source String?
The source code for the reflectee, if available. Otherwise null.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited