isRegularMethod property

  1. @override
bool get isRegularMethod
override

Is the reflectee a regular function or method?

A function or method is regular if it is not a getter, setter, or constructor. Note that operators, by this definition, are regular methods.

Required capabilities: isRegularMethod does not require any capabilities.

Implementation

@override
bool get isRegularMethod => kind == constants.method;