namesOfNamedParameters property

Set<Symbol> get namesOfNamedParameters

Returns the Set of Symbols used for named parameters of this method; computed based on the given parameter mirrors, then cached.

Implementation

Set<Symbol> get namesOfNamedParameters {
  if (_namesOfNamedParameters == null) _setupParameterListInfo();
  return _namesOfNamedParameters!;
}