ReflectionImpl class abstract

Implemented types
Implementers

Constructors

ReflectionImpl([ReflectCapability? cap0, ReflectCapability? cap1, ReflectCapability? cap2, ReflectCapability? cap3, ReflectCapability? cap4, ReflectCapability? cap5, ReflectCapability? cap6, ReflectCapability? cap7, ReflectCapability? cap8, ReflectCapability? cap9])
Const constructor, to enable usage as metadata, allowing for varargs style invocation with up to ten arguments.
const
ReflectionImpl.fromList(List<ReflectCapability> capabilities)
const

Properties

annotatedClasses Iterable<ClassMirror>
Returns an Iterable of all the classes that can be reflected over in this Reflection.
no setteroverride
capabilities List<ReflectCapability>
Specifies limits on the support for reflective operations on instances of classes having an instance of this ReflectionBase as metadata.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
libraries Map<Uri, LibraryMirror>
Returns a map of all libraries in the current isolate.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canReflect(Object reflectee) bool
Returns true if this reflector has capabilities for the given instance.
override
canReflectType(Type type) bool
Returns true if this reflector has capabilities for the given Type.
override
findLibrary(String libraryName) LibraryMirror
Returns a mirror of the given library library.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reflect(Object reflectee) InstanceMirror
Returns a mirror of the given object reflectee.
override
reflectType(Type type) TypeMirror
Returns a mirror of the given type type.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited