getters property

Map<String, InvokerOfGetter> getters
final

Map from getter names to closures accepting an instance and returning the result of invoking the getter with that name on that instance.

Implementation

final Map<String, InvokerOfGetter> getters;