libraryMirrors property
List of library mirrors, one library mirror for each library that is supported by reflection as specified by the reflector backed up by this ReflectorData.
Implementation
final List<LibraryMirror>? libraryMirrors;
List of library mirrors, one library mirror for each library that is supported by reflection as specified by the reflector backed up by this ReflectorData.
final List<LibraryMirror>? libraryMirrors;