TypeVariableMirrorImpl<T extends Object> class

Implemented types

Constructors

TypeVariableMirrorImpl(String simpleName, String qualifiedName, ReflectionImpl _reflector, int? _upperBoundIndex, int _ownerIndex, List<Object>? _metadata)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasReflectedType bool
Returns true if this mirror reflects dynamic, a non-generic class or typedef, or an instantiated generic class or typedef with support in the execution mode. Otherwise, returns false.
no setteroverride
isNonNullable bool
Returns true iff this type mirror represents a non-nullable type.
no setteroverride
isNullable bool
Returns true iff this type mirror represents a nullable type.
no setteroverride
isOriginalDeclaration bool
Is this the original declaration of this type?
no setteroverride
isPotentiallyNonNullable bool
Returns true iff this type mirror represents a potentially non-nullable type.
no setteroverride
isPotentiallyNullable bool
Returns true iff this type mirror represents a potentially nullable type.
no setteroverride
isPrivate bool
Whether this declaration is library private.
no setteroverride
isStatic bool
Is the reflectee static? For the purposes of the mirrors library, type variables are considered non-static.
no setteroverride
isTopLevel bool
Whether this declaration is top-level.
no setteroverride
location SourceLocation
The source location of this Dart language entity, or null if the entity is synthetic.
no setteroverride
metadata List<Object>
A list of the metadata associated with this declaration.
no setteroverride
originalDeclaration TypeMirror
A mirror on the original declaration of this type.
no setteroverride
owner DeclarationMirror
A mirror on the owner of this Dart language entity.
no setteroverride
qualifiedName String
The qualified name of this type variable, i.e., the qualified name of the declaring class followed by its simple name.
final
reflectedGenericType Type
no setteroverride
reflectedType Type
If hasReflectedType returns true, returns the corresponding Type. Otherwise, an UnsupportedError is thrown.
no setteroverride
reflectedTypeArguments List<Type>
An immutable list with Type values for the actual type arguments of this type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleName String
The simple name of this type variable.
final
typeArguments List<TypeMirror>
An immutable list with mirrors for all type arguments for this type.
no setteroverride
typeVariables List<TypeVariableMirror>
An immutable list with mirrors for all type variables for this type.
no setteroverride
upperBound TypeMirror
A mirror on the type that is the upper bound of this type variable.
no setteroverride

Methods

createKeyedMap<V>() Map<T, V>
override
createKeyedValuedMap() Map<T, T>
override
createList() List<T>
override
createNullableList() List<T?>
override
createNullableSet() Set<T?>
override
createNullableValuedMap<K>() Map<K, T?>
override
createSet() Set<T>
override
createValuedMap<K>() Map<K, T>
override
isAssignableTo(TypeMirror other) bool
Checks the assignability relationship, denoted by <=> in the language specification. This is the type relationship tested on assignment in checked mode.
override
isInstanceOf(Object? object) bool
override
isSubtype<S>() bool
override
isSubtypeOf(TypeMirror other) bool
Checks the subtype relationship, denoted by <: in the language specification.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited