VariableMirrorImpl class

Implemented types

Constructors

VariableMirrorImpl(String name, int descriptor, int ownerIndex, ReflectionImpl reflection, int classMirrorIndex, int reflectedTypeIndex, int dynamicReflectedTypeIndex, List<int>? reflectedTypeArguments, List<Object>? metadata)

Properties

dynamicReflectedType Type
If hasDynamicReflectedType is true, returns the corresponding Type as specified for dynamicReflectedType in ClassMirror. Otherwise, an UnsupportedError is thrown.
no setterinherited
hasDynamicReflectedType bool
Returns the value specified with hasDynamicReflectedType in ClassMirror, but for the type given by the annotation of the variable modeled by this mirror.
no setterinherited
hashCode int
Override requested by linter.
no setter
hasReflectedType bool
Returns the value specified with hasReflectedType in TypeMirror, but for the type given by the annotation of the variable modeled by this mirror.
no setterinherited
isConst bool
Returns true if the reflectee is declared const. Otherwise returns false.
no setteroverride
isFinal bool
Returns true if the reflectee is a final variable. Otherwise returns false.
no setterinherited
isPrivate bool
Whether this declaration is library private.
no setterinherited
isStatic bool
Returns true if the reflectee is a static variable. Otherwise returns false.
no setteroverride
isTopLevel bool
Whether this declaration is top-level.
no setterinherited
kind int
no setterinherited
location SourceLocation
The source location of this Dart language entity, or null if the entity is synthetic.
no setterinherited
metadata List<Object>
A list of the metadata associated with this declaration.
no setterinherited
owner DeclarationMirror
A mirror on the owner of this Dart language entity.
no setteroverride
qualifiedName String
The fully-qualified name for this Dart language entity.
no setterinherited
reflectedType Type
If hasReflectedType is true, returns the corresponding Type. Otherwise, an UnsupportedError is thrown.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleName String
The simple name for this Dart language entity.
no setterinherited
type TypeMirror
Returns a mirror on the type of the reflectee.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Override requested by linter.