mirrors
library
Classes
-
ClassMirror<T>
-
A ClassMirror reflects a Dart language class.
-
ClosureMirror
-
A ClosureMirror reflects a closure.
-
CombinatorMirror
-
A mirror on a show/hide combinator declared on a library dependency.
-
Class used for encoding comments as metadata annotations.
-
DeclarationMirror
-
A DeclarationMirror reflects some entity declared in a Dart program.
-
FunctionTypeMirror<T>
-
A FunctionTypeMirror represents the type of a function in the
Dart language.
-
InstanceMirror
-
An InstanceMirror reflects an instance of a Dart language object.
-
LibraryDependencyMirror
-
A mirror on an import or export declaration.
-
LibraryMirror
-
A LibraryMirror reflects a Dart language library, providing
access to the variables, functions, and classes of the
library.
-
MethodMirror
-
A MethodMirror reflects a Dart language function, method,
constructor, getter, or setter.
-
Mirror
-
The base class for all mirrors.
-
ObjectMirror
-
An ObjectMirror is a common superinterface of InstanceMirror,
ClassMirror, and LibraryMirror that represents their shared
functionality.
-
ParameterMirror
-
A ParameterMirror reflects a Dart formal parameter declaration.
-
SourceLocation
-
A SourceLocation describes the span of an entity in Dart source code.
-
TypedefMirror<T>
-
A TypedefMirror represents a typedef in a Dart language program.
-
TypeMirror<T>
-
A TypeMirror reflects a Dart language class, typedef,
function type or type variable.
-
TypeValue<E>
-
Used to obtain values of type Type.
-
TypeVariableMirror<T>
-
A TypeVariableMirror represents a type parameter of a generic type.
-
VariableMirror
-
A VariableMirror reflects a Dart language variable declaration.