generated library
Internal exports for generated reflection code.
This library exports the internal APIs that generated .reflection.dart
files need to import. It should not be used directly by user code.
Classes
-
ClassMirror<
T> - A ClassMirror reflects a Dart language class.
- ClosureMirror
- A ClosureMirror reflects a closure.
- CombinatorMirror
- A mirror on a show/hide combinator declared on a library dependency.
- Comment
- Class used for encoding comments as metadata annotations.
- DeclarationMirror
- A DeclarationMirror reflects some entity declared in a Dart program.
- FakeType
-
FunctionTypeMirror<
T> - A FunctionTypeMirror represents the type of a function in the Dart language.
-
GenericClassMirrorImpl<
T extends Object> - ImplicitGetterMirrorImpl
- ImplicitSetterMirrorImpl
- InstanceMirror
- An InstanceMirror reflects an instance of a Dart language object.
- LibraryDependencyMirror
- A mirror on an import or export declaration.
- LibraryMirror
- A LibraryMirror reflects a Dart language library, providing access to the variables, functions, and classes of the library.
- LibraryMirrorImpl
- MethodMirror
- A MethodMirror reflects a Dart language function, method, constructor, getter, or setter.
- MethodMirrorImpl
- Mirror
- The base class for all mirrors.
-
NonGenericClassMirrorImpl<
T extends Object> - ObjectMirror
- An ObjectMirror is a common superinterface of InstanceMirror, ClassMirror, and LibraryMirror that represents their shared functionality.
- ParameterMirror
- A ParameterMirror reflects a Dart formal parameter declaration.
- ParameterMirrorImpl
- ReflectionImpl
- ReflectorData
- The data backing a reflector.
- SourceLocation
- A SourceLocation describes the span of an entity in Dart source code.
-
TypedefMirror<
T> - A TypedefMirror represents a typedef in a Dart language program.
-
TypeMirror<
T> - A TypeMirror reflects a Dart language class, typedef, function type or type variable.
-
TypeValue<
E> - Used to obtain values of type Type.
-
TypeVariableMirror<
T> - A TypeVariableMirror represents a type parameter of a generic type.
-
TypeVariableMirrorImpl<
T extends Object> - VariableMirror
- A VariableMirror reflects a Dart language variable declaration.
- VariableMirrorImpl
Properties
-
data
↔ Map<
Reflection, ReflectorData> -
This mapping contains the mirror-data for each reflector.
It will be initialized in the generated code.
getter/setter pair
-
memberSymbolMap
↔ Map<
Symbol, String> ? -
This mapping translates symbols to strings for the covered members.
It will be initialized in the generated code.
getter/setter pair