metadata property
A list of the metadata associated with this declaration.
Let D be the declaration this mirror reflects. If D is decorated with annotations A1, ..., An where n > 0, then for each annotation Ai associated with D, 1 <= i <= n, let ci be the constant object specified by Ai. Then this method returns a list whose members c1, ..., cn. If no annotations are associated with D, then an empty list is returned.
If evaluating any of c1, ..., cn would cause a compilation error the effect is the same as if a non-reflective compilation error had been encountered.
Note that the return type of the corresponding method in
dart:mirrors is List<InstanceMirror>.
Required capabilities: metadata requires a MetadataCapability.
Implementation
@override
List<Object> get metadata => <Object>[];