LibraryMirrorImpl class
- Implemented types
Constructors
Properties
-
declarations
→ Map<
String, DeclarationMirror> -
Returns an immutable map of the declarations actually given in the
library.
no setteroverride
-
getters
→ Map<
String, StaticGetter> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPrivate → bool
-
A library cannot be private.
no setteroverride
- isTopLevel → bool
-
Whether this declaration is top-level.
no setteroverride
-
libraryDependencies
→ List<
LibraryDependencyMirror> -
Returns a list of the imports and exports in this library;
no setteroverride
- location → SourceLocation
-
The source location of this Dart language entity, or
nullif the entity is synthetic.no setteroverride -
metadata
→ List<
Object> -
A list of the metadata associated with this declaration.
no setteroverride
- owner → Null
-
A mirror on the owner of this Dart language entity.
no setteroverride
- qualifiedName → String
-
The fully-qualified name for this Dart language entity.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setters
→ Map<
String, InvokerOfGetter> -
final
- simpleName → String
-
The simple name for this Dart language entity.
final
- uri → Uri
-
The absolute uri of the library.
final
Methods
-
invoke(
String memberName, List positionalArguments, [Map< Symbol, dynamic> ? namedArguments]) → Object? -
Invokes the function or method
memberName, and returns the result.override -
invokeGetter(
String getterName) → Object? -
Invokes a getter and returns the result. The getter can be the
implicit getter for a field, or a user-defined getter method.
override
-
invokeSetter(
String name, Object? value) → Object? -
Invokes a setter and returns the result. The setter may be either
the implicit setter for a non-final field, or a user-defined setter
method. The name of the setter can include the final
=; if it is not present, it will be added.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override