MethodMirrorImpl class
Properties
constructorName
→ String
The constructor name for named constructors and factory methods.
no setter override
dynamicReflectedReturnType
→ Type
If hasDynamicReflectedReturnType is true, returns the corresponding
Type as specified for dynamicReflectedType in ClassMirror .
Otherwise, an UnsupportedError is thrown.
no setter override
hasDynamicReflectedReturnType
→ bool
Returns the value specified with hasDynamicReflectedType in
ClassMirror , but for the return type given by the annotation of the
method modeled by this mirror.
no setter override
hashCode
→ int
The hash code for this object.
no setter inherited
hasReflectedReturnType
→ bool
Returns the value specified with hasReflectedType in TypeMirror ,
but for the return type given by the annotation of the method modeled
by this mirror.
no setter override
isAbstract
→ bool
Is the reflectee abstract?
no setter override
isConstConstructor
→ bool
Is the reflectee a const constructor?
no setter override
isConstructor
→ bool
Is the reflectee a constructor?
no setter override
isFactoryConstructor
→ bool
Is the reflectee a factory constructor?
no setter override
isGenerativeConstructor
→ bool
Is the reflectee a generative constructor?
no setter override
isGetter
→ bool
Is the reflectee a getter?
no setter override
isOperator
→ bool
Is the reflectee an operator?
no setter override
isPrivate
→ bool
Whether this declaration is library private.
no setter override
isRedirectingConstructor
→ bool
Is the reflectee a redirecting constructor?
no setter override
isRegularMethod
→ bool
Is the reflectee a regular function or method?
no setter override
isSetter
→ bool
Is the reflectee a setter?
no setter override
isStatic
→ bool
A function is considered non-static iff it is permited to refer to 'this'.
no setter override
isSynthetic
→ bool
Returns true if the reflectee is synthetic, and returns false otherwise.
no setter override
isTopLevel
→ bool
Whether this declaration is top-level.
no setter override
kind
→ int
no setter
location
→ SourceLocation
The source location of this Dart language entity, or null if the
entity is synthetic.
no setter override
metadata
→ List <Object >
A list of the metadata associated with this declaration.
no setter override
namesOfNamedParameters
→ Set <Symbol >
Returns the Set of Symbol s used for named parameters of this method;
computed based on the given parameter mirrors, then cached.
no setter
numberOfOptionalPositionalParameters
→ int
Returns the number of optional positional parameters of this method;
computed from the given parameter mirrors, then cached.
no setter
numberOfPositionalParameters
→ int
Returns the number of positional parameters of this method; computed
from the given parameter mirrors, then cached.
no setter
owner
→ DeclarationMirror
A mirror on the owner of this Dart language entity.
no setter override
parameters
→ List <ParameterMirror >
A list of mirrors on the parameters for the reflectee.
no setter override
qualifiedName
→ String
The fully-qualified name for this Dart language entity.
no setter override
reflectedReturnType
→ Type
If hasReflectedReturnType is true, returns the corresponding Type .
Otherwise, an UnsupportedError is thrown.
no setter override
returnType
→ TypeMirror
A mirror on the return type for the reflectee.
no setter override
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
simpleName
→ String
The simple name for this Dart language entity.
no setter override
source
→ String ?
The source code for the reflectee, if available. Otherwise null.
no setter override
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
override