memberMirrors property
Repository of method mirrors used (via indices into this list) by the
class mirrors in typeMirrors to describe the behavior of the mirrored
class and its instances, and of variable mirrors used to describe
their state. From the behavioral point of view there are no fields,
but each of them gives rise to a getter and possibly a setter (whose
isSynthetic is true). The implicit getters/setters are not stored
in this list, but they can be reconstructed based on the variable
mirrors describing the fields. From the program structure point of
view (used for declarations), the method mirrors and the field
mirrors must both be included directly. Hence, both points of view
require a little bit of processing, but in return we avoid some
redundancy in the stored information.
Implementation
final List<DeclarationMirror>? memberMirrors;