parameterListShapes property
List of parameter list shapes. Each entry is a list containing data on
one shape of parameter list. The same shape is shared, e.g., by methods
like void foo(int a, [String b]) and List bar(x, [y]) because the
shape is independent of type annotations and names, and only describes
the number and kind of parameters. It is represented as a list containing
three elements: An int specifying the number of positional parameters,
an int describing the number of optional positional parameters, and a
List containing Symbol values for the names of named parameters.
Implementation
final List<List>? parameterListShapes;